function pendelMpr

%Initialising
N=100;
T=10;
h=T/N;

%number of newton iterations
nNewton=1;

%right hand side of the pendulum equation, as well as its Jacobian
f=@(y) [y(2); -sin(y(1))];
Df=@(y) [0 1; -cos(y(1)) 0];

%function for the finding roots problem transformation and its Jacobian
F=@(y,y0) y-y0-h*f((y0+y)/2);
DF=@(y,y0) eye(length(y))-h/2*Df((y0+y)/2);

%energy function (Hamilton function)
H=@(y) 0.5*y(2)^2-cos(y(1));

%initial conditions
y=[pi/2;0];

%array in which the evolution of the energy is saved
energy=zeros(N+1,1);
energy(1)=H(y);

for ii=1:N
    %perform one step of the implicit midpoint method
    y0=y;
    %with nNewton steps
    for jj=1:nNewton
        y=y-DF(y,y0)\F(y,y0);
        
    end
    %save the energy
    energy(ii+1)=H(y);
end

%plot the evolution of the energy
figure;
plot(0:h:T,energy,'*-')
    