function [t, p, q] = SympEuler(p0, q0, tspan, h)
% symplectic Euler for
% 
%  [p',q'] = [p,q]/(p^2 + q^2)
%
% Input paramters:
% p0: initial value for p
% q0: initial value for q
% tspan: [t0, T] starting and stopping time
% h: timestep size
%
% Outputparameters
% t: dicrete time points
% p: solution for p at time points
% q: solution for q at time points

% Time intervall
% number of time steps
N = ceil(diff(tspan)/h);
h = diff(tspan)/N;
t = linspace(tspan(1),tspan(2),N+1);

% memory allocation
p = zeros(1,N+1); p(1) = p0;
q = zeros(1,N+1); q(1) = q0;

% functions for each equation
dp = @(P,Q) (P/(P^2 + Q^2));
dq = @(P,Q) (Q/(P^2 + Q^2));

for k = 2:length(t)
  % solve p implicitly
  F = @(P) (p(k-1) + h*dp(P,q(k-1)) - P);
  options = optimset('Display','off');  % Turn off Display
  p(k) = fsolve(F,p(k-1),options);
  
  % calculate q explicitly
  q(k) = q(k-1) + h*dq(p(k),q(k-1));
end