% Invariant
H=@(p,q) -imag(log(p+i*q));

% allocate memory
kmax = 7;
h = (1/2).^(1:kmax);
N = length(h);
err_rk = zeros(1,N);
err_se = zeros(1,N);

% stop time
T = 1;

% initial data
p0 = 3;
q0 = 4;

for k = 1:N
  [t, prk, qrk] = RK4(p0, q0, [0 T], h(k));
  H_rk = H(prk, qrk);
  diff_rk(k) = max(H_rk) - min(H_rk);
  
  [t, pse, qse] = SympEuler(p0, q0, [0 T], h(k));
  H_se = H(pse, qse);
  diff_se(k) = max(H_se) - min(H_se);
end

figure(1)
loglog(h,diff_rk,'r*-', h, h.^4/10^10, 'k-.',h, diff_se, 'b+-', h, h, 'k:')
legend('Runge-Kutta', 'Order 4', 'Symplectic Euler', 'Order 1',...
       'Location','SouthEast')
grid on;   
print -depsc 'errorVar.eps'